@@ -6,7 +6,7 @@
 				return;
 			}
 
-			$paging = new pagination($this->output, "admin_users", ADMIN_PAGE_SIZE, $user_count);
+			$paging = new pagination($this->output, "admin_users", $this->settings->admin_page_size, $user_count);
 
 			$users = $this->model->get_all_users($paging->offset, $paging->size);
 			$roles = $this->model->get_all_roles();
