@@ -28,13 +28,18 @@
 				"type"     => "boolean",
 				"default"  => true,
 				"overview" => true,
-				"required" => true));
+				"required" => true),
+			"errors" => array(
+				"label"    => "Errors",
+				"type"     => "integer",
+				"default"  => 0,
+				"overview" => false,
+				"readonly" => true));
 
 		public function delete_item($item_id) {
 			$queries = array(
 				array("delete from events where webserver_id=%d", $item_id),
 				array("delete from host_statistics where webserver_id=%d", $item_id),
-				array("delete from requests where webserver_id=%d", $item_id),
 				array("delete from server_statistics where webserver_id=%d", $item_id),
 				array("delete from webservers where id=%d", $item_id));
 
