@@ -66,12 +66,10 @@
 		/* Main menu
 		 */
 		if (is_true(WEBSITE_ONLINE) && $_user->logged_in) {
-			if ($_output->fetch_from_cache("menu") == false) {
-				$_output->start_caching("menu");
-				$menu = new menu($_database, $_output);
-				$menu->to_output(0, 2, $_page->page);
-				$_output->stop_caching();
-			}
+			$menu = new menu($_database, $_output);
+			$menu->set_user($_user);
+			$menu->set_depth(2);
+			$menu->to_output();
 		}
 
 		/* Stylesheet
